pub struct ProcessArgs {Show 22 fields
pub input: PathBuf,
pub output: Option<PathBuf>,
pub schema: Option<PathBuf>,
pub index: Option<PathBuf>,
pub index_variant: Option<String>,
pub sort: Vec<String>,
pub columns: Vec<String>,
pub exclude_columns: Vec<String>,
pub derives: Vec<String>,
pub filters: Vec<String>,
pub filter_exprs: Vec<String>,
pub row_numbers: bool,
pub limit: Option<usize>,
pub delimiter: Option<u8>,
pub output_delimiter: Option<u8>,
pub input_encoding: Option<String>,
pub output_encoding: Option<String>,
pub boolean_format: BooleanFormat,
pub preview: bool,
pub table: bool,
pub apply_mappings: bool,
pub skip_mappings: bool,
}Fields
input: PathBufInput CSV file to process
output: Option<PathBuf>Output CSV file (stdout if omitted)
schema: Option<PathBuf>Schema file to drive typed operations and apply value replacements
index: Option<PathBuf>Existing index file to speed up operations
index_variant: Option<String>Specific index variant name to use from the selected index file
sort: Vec<String>Sort directives of the form column[:asc|desc]
columns: Vec<String>Restrict output to this comma-separated list of columns
exclude_columns: Vec<String>Exclude this comma-separated list of columns from output
derives: Vec<String>Additional derived columns using name=expression
filters: Vec<String>Row-level filters such as amount>=100 or status = shipped
filter_exprs: Vec<String>Evalexpr-based filter expressions that must evaluate to truthy values
row_numbers: boolEmit 1-based row numbers as the first column
limit: Option<usize>Limit number of rows emitted
delimiter: Option<u8>CSV delimiter character for reading input
output_delimiter: Option<u8>Delimiter to use for output (defaults to input delimiter)
input_encoding: Option<String>Character encoding of the input file (defaults to utf-8)
output_encoding: Option<String>Character encoding for the output file/stdout (defaults to utf-8)
boolean_format: BooleanFormatNormalize boolean columns in output
preview: boolRender results as a preview table on stdout (disables –output and defaults the row limit)
table: boolRender output as an elastic table to stdout
apply_mappings: boolApply schema-defined datatype mappings before replacements (auto when available)
skip_mappings: boolSkip schema-defined datatype mappings even if they exist