pub struct IndexArgs {
pub input: PathBuf,
pub index: PathBuf,
pub columns: Vec<String>,
pub specs: Vec<String>,
pub coverings: Vec<String>,
pub schema: Option<PathBuf>,
pub limit: Option<usize>,
pub delimiter: Option<u8>,
pub input_encoding: Option<String>,
}Fields
input: PathBufInput CSV file to index
index: PathBufOutput index file (.idx)
columns: Vec<String>Columns to include in a single ascending index (deprecated when –spec is used)
specs: Vec<String>Repeatable index specifications such as col_a:asc,col_b:desc or fast=col_a:asc
coverings: Vec<String>Generate covering index variants by expanding column prefixes and direction combinations (use | to separate directions)
schema: Option<PathBuf>Optional schema file describing column types
limit: Option<usize>Limit number of rows to scan (useful for prototyping)
delimiter: Option<u8>CSV delimiter character (supports ‘,’, ‘tab’, ‘;’, ‘|’)
input_encoding: Option<String>Character encoding of the input file (defaults to utf-8)