pub struct StatsArgs {
pub input: PathBuf,
pub schema: Option<PathBuf>,
pub columns: Vec<String>,
pub filters: Vec<String>,
pub filter_exprs: Vec<String>,
pub delimiter: Option<u8>,
pub input_encoding: Option<String>,
pub limit: usize,
pub frequency: bool,
pub top: usize,
}Fields
input: PathBufInput CSV file to profile
schema: Option<PathBuf>Schema file to drive typed operations
columns: Vec<String>Columns to include (defaults to numeric columns)
filters: Vec<String>Row-level filters such as amount>=100 or status = shipped
filter_exprs: Vec<String>Evalexpr-based filter expressions that must evaluate to truthy values
delimiter: Option<u8>CSV delimiter character
input_encoding: Option<String>Character encoding for input file (defaults to utf-8)
limit: usizeMaximum rows to scan (0 = all)
frequency: boolEmit distinct value counts instead of summary statistics
top: usizeMaximum distinct values to display per column when –frequency is used (0 = all)